[Fusionforge-commits] r8486 - trunk/gforge/common/frs

Alain Peyrat aljeux at libremir.placard.fr.eu.org
Wed Dec 9 21:15:26 CET 2009


Author: aljeux
Date: 2009-12-09 21:15:26 +0100 (Wed, 09 Dec 2009)
New Revision: 8486

Modified:
   trunk/gforge/common/frs/FRSRelease.class.php
Log:
FRS: small improvements and remove wrap in emails to avoid breaking links

Modified: trunk/gforge/common/frs/FRSRelease.class.php
===================================================================
--- trunk/gforge/common/frs/FRSRelease.class.php	2009-12-09 20:15:20 UTC (rev 8485)
+++ trunk/gforge/common/frs/FRSRelease.class.php	2009-12-09 20:15:26 UTC (rev 8486)
@@ -168,7 +168,9 @@
 			return false;
 		} else {
 			$newdirlocation = $GLOBALS['sys_upload_dir'].'/'.$this->FRSPackage->Group->getUnixName().'/'.$this->FRSPackage->getFileName().'/'.$this->getFileName();
-			exec("/bin/mkdir $newdirlocation",$out);
+			if (!is_dir($newdirlocation)) {
+				@mkdir($newdirlocation);
+			}
 			db_commit();
 			return true;
 		}
@@ -303,7 +305,7 @@
 					      util_make_url ("/frs/?group_id=". $this->FRSPackage->Group->getID() ."&release_id=". $this->getID()),
 					      $GLOBALS['sys_name'],
 					      util_make_url ("/frs/monitor.php?filemodule_id=".$this->FRSPackage->getID()."&group_id=".$this->FRSPackage->Group->getID()."&stop=1")));
-		$text = util_line_wrap($text);
+//		$text = util_line_wrap($text);
 		if (count($arr)) {
 			util_handle_message(array_unique($arr),$subject,$text);
 		}
@@ -371,7 +373,7 @@
 	}
 
 	/**
 	 *	create - create a new release in the database.
 	 *
 	 *	@param	int	The status of this release from the frs_status table.
 	 *	@param	string	The name of the release.
@@ -405,7 +407,7 @@
 						array ($this->FRSPackage->getID(),
 						       htmlspecialchars($name))) ;
 			if (db_numrows($res)) {
-				$this->setError('FRSRelease::create() Error Adding Release: Name Already Exists');
+				$this->setError('FRSRelease::update() Error On Update: Name Already Exists');
 				return false;
 			}
 		}		
@@ -371,7 +373,7 @@
 
 	/**
-	 *	create - create a new release in the database.
+	 *	update - update a new release in the database.
 	 *
 	 *	@param	int	The status of this release from the frs_status table.




More information about the Fusionforge-commits mailing list